@@ -780,11 +780,11 @@ def processAutolinks(doc):
         if linkType in ("property", "descriptor", "propdesc") and "*" in linkText:
             continue
 
-        # Not super clear why I think links will specify multiple for values,
-        # or why it's okay to just use the first one in that case.
-        linkFor = config.splitForValues(el.get('data-link-for'))
-        if linkFor:
-            linkFor = linkFor[0]
+        # Links can have multiple for values in cases like IDL constructors,
+        # where there are several valid ways to set up the dfn
+        # and my autogenerated links want to make sure that they'll link successfully
+        # to any variant that the spec author uses.
+        linkFors = config.splitForValues(el.get('data-link-for'))
 
         # Status used to use ED/TR, so convert those if they appear,
         # and verify
@@ -802,7 +802,7 @@ def processAutolinks(doc):
         ref = doc.refs.getRef(linkType, linkText,
                               spec=el.get('data-link-spec'),
                               status=status,
-                              linkFor=linkFor,
+                              linkFor=linkFors,
                               linkForHint=el.get('data-link-for-hint'),
                               explicitFor=doc.md.assumeExplicitFor,
                               el=el,
