@@ -1,10 +1,14 @@
 # -*- coding: utf-8 -*-
 
 
+import asyncio
+import aiofiles
+import aiohttp
 import hashlib
 import io
 import os
 import requests
+import time
 from datetime import datetime
 
 from ..messages import *
@@ -33,6 +37,8 @@ knownFolders = [
     "mdn",
 ]
 
+ghPrefix = "https://raw.githubusercontent.com/tabatkins/bikeshed-data/master/data/"
+
 def createManifest(path, dryRun=False):
     '''Generates a manifest file for all the data files.'''
     manifests = []
@@ -85,7 +91,6 @@ def updateByManifest(path, dryRun=False):
     Returns False if updating failed and a full update should be performed;
     returns True if updating was a success.
     '''
-    ghPrefix = "https://raw.githubusercontent.com/tabatkins/bikeshed-data/master/data/"
     say("Updating via manifest...")
     try:
         with io.open(os.path.join(path, "manifest.txt"), 'r', encoding="utf-8") as fh:
@@ -138,33 +143,9 @@ def updateByManifest(path, dryRun=False):
             print("Deleted {0} old data file{1}.".format(len(deletedPaths), "s" if len(deletedPaths) > 1 else ""))
 
     if not dryRun:
-        import time
-        messageDelta = 2.5 # wall time
-        lastMsgTime = time.time()
         if newPaths:
             say("Updating {0} file{1}...", len(newPaths), "s" if len(newPaths) > 1 else "")
-        for i,filePath in enumerate(newPaths):
-            remotePath = ghPrefix + filePath
-            localPath = localizePath(path, filePath)
-            try:
-                newFile = requests.get(remotePath).text
-            except Exception as e:
-                warn("Couldn't download file '{0}'.\n{1}", remotePath, e)
-                return False
-            try:
-                dirPath = os.path.dirname(localPath)
-                if not os.path.exists(dirPath):
-                    os.makedirs(dirPath)
-                with io.open(localPath, 'w', encoding="utf-8") as fh:
-                    fh.write(newFile)
-            except Exception as e:
-                warn("Couldn't save file '{0}'.\n{1}", localPath, e)
-                return False
-
-            currFileTime = time.time()
-            if (currFileTime - lastMsgTime) >= messageDelta:
-                say("Updated {0}/{1}...", i+1, len(newPaths))
-                lastMsgTime = currFileTime
+        asyncio.run(updateFiles(path, newPaths))
         try:
             with io.open(os.path.join(path, "manifest.txt"), 'w', encoding="utf-8") as fh:
                 fh.write("\n".join(remoteManifest))
@@ -174,6 +155,54 @@ def updateByManifest(path, dryRun=False):
     say("Done!")
     return True
 
+async def updateFiles(localPrefix, newPaths):
+    tasks = set()
+    async with aiohttp.ClientSession() as session:
+        for filePath in newPaths:
+            coro = updateFile(localPrefix, filePath, session=session)
+            tasks.add(coro)
+
+        lastMsgTime = time.time()
+        messageDelta = 2
+        i = 0
+        for coro in asyncio.as_completed(tasks):
+            i += 1
+            await coro
+            currFileTime = time.time()
+            if (currFileTime - lastMsgTime) >= messageDelta:
+                say("Updated {0}/{1}...", i, len(newPaths))
+                lastMsgTime = currFileTime
+
+async def updateFile(localPrefix, filePath, session):
+    remotePath = ghPrefix + filePath
+    localPath = localizePath(localPrefix, filePath)
+    data = await downloadFile(remotePath, session)
+    if data is None:
+        return
+    await saveFile(localPath, data)
+
+async def downloadFile(path, session):
+    try:
+        resp = await session.request(method='GET', url=path)
+        resp.raise_for_status()
+        return await resp.text()
+    except Exception as e:
+        warn("Couldn't download file '{0}'.\n{1}", path, e)
+        return
+
+async def saveFile(path, data):
+    try:
+        dirPath = os.path.dirname(path)
+        if not os.path.exists(dirPath):
+            os.makedirs(dirPath)
+        async with aiofiles.open(path, 'w', encoding="utf-8") as fh:
+            await fh.write(data)
+    except Exception as e:
+        warn("Couldn't save file '{0}'.\n{1}", path, e)
+        return False
+
+
+
 
 def localizePath(root, relPath):
     return os.path.join(root, *relPath.split("/"))
